pub struct BidirectedAdjacencyArray<IndexType: GraphIndexInteger, NodeData, EdgeData> { /* private fields */ }Implementations
Sourceimpl<IndexType: GraphIndexInteger, NodeData, EdgeData> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>
impl<IndexType: GraphIndexInteger, NodeData, EdgeData> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>
Sourcepub fn new(
nodes: TaggedVec<NodeIndex<IndexType>, NodeData>,
edges: TaggedVec<EdgeIndex<IndexType>, BidirectedEdge<IndexType, EdgeData>>,
) -> Self
pub fn new( nodes: TaggedVec<NodeIndex<IndexType>, NodeData>, edges: TaggedVec<EdgeIndex<IndexType>, BidirectedEdge<IndexType, EdgeData>>, ) -> Self
Creates a bidirected adjacency array with the given bidirected nodes and edges.
Example
use bidirected_adjacency_array::graph::BidirectedAdjacencyArray;
use bidirected_adjacency_array::index::{NodeIndex, EdgeIndex};
use bidirected_adjacency_array::graph::BidirectedEdge;
use tagged_vec::TaggedVec;
let nodes = TaggedVec::from(vec!['A', 'B', 'C']);
let edges = TaggedVec::from(vec![
BidirectedEdge::new(NodeIndex::from_usize(0).into_directed_forward(), NodeIndex::from_usize(1).into_directed_forward(), 1), // A+ -> B+
BidirectedEdge::new(NodeIndex::from_usize(1).into_directed_reverse(), NodeIndex::from_usize(2).into_directed_forward(), 2), // B- -> C+
]);
let graph = BidirectedAdjacencyArray::<u8, _, _>::new(nodes, edges);Sourcepub fn reorder_edges(
&mut self,
node: DirectedNodeIndex<IndexType>,
comparator: impl FnMut(DirectedNodeIndex<IndexType>, DirectedNodeIndex<IndexType>) -> Ordering,
)
pub fn reorder_edges( &mut self, node: DirectedNodeIndex<IndexType>, comparator: impl FnMut(DirectedNodeIndex<IndexType>, DirectedNodeIndex<IndexType>) -> Ordering, )
Reorder the edges of the given node according to the given comparator.
The comparator receives two different to-nodes, representing the two edges from the given node to these to-nodes.
Sourcepub fn remove_multiedges(&mut self) -> BTreeSet<EdgeIndex<IndexType>>
pub fn remove_multiedges(&mut self) -> BTreeSet<EdgeIndex<IndexType>>
Removes multiedges between the same pair of directed nodes, keeping only one of them.
Warning: This does not check if the edge data of the multiedges is actually the same, and simply keeps one of them. It is the caller’s responsibility to ensure that this is the case if they want to keep the data consistent.
Returns the indices of the removed edges. Note that this method shifts the edge indices, and hence the returned indices now respond to different edges in the graph, or possibly no edge at all.
pub fn node_count(&self) -> usize
pub fn edge_count(&self) -> usize
pub fn iter_nodes(&self) -> impl Iterator<Item = NodeIndex<IndexType>>
pub fn iter_edges(&self) -> impl Iterator<Item = EdgeIndex<IndexType>>
pub fn iter_outgoing_edges( &self, node: DirectedNodeIndex<IndexType>, ) -> impl Iterator<Item = DirectedEdge<IndexType>>
Sourcepub fn iter_incident_edges(
&self,
node: NodeIndex<IndexType>,
) -> impl Iterator<Item = EdgeIndex<IndexType>>
pub fn iter_incident_edges( &self, node: NodeIndex<IndexType>, ) -> impl Iterator<Item = EdgeIndex<IndexType>>
Iterate over the bidirected edges incident to the given bidirected node.
pub fn node_data(&self, node: NodeIndex<IndexType>) -> &NodeData
pub fn edge( &self, edge: EdgeIndex<IndexType>, ) -> EdgeView<'_, IndexType, EdgeData>
pub fn directed_edge_data<'this>( &'this self, directed_edge: DirectedEdgeIndex<IndexType>, ) -> DirectedEdgeDataView<'this, IndexType, EdgeData>
pub fn directed_edge_into_bidirected( &self, directed_edge: DirectedEdgeIndex<IndexType>, ) -> EdgeIndex<IndexType>
Sourceimpl<IndexType: GraphIndexInteger, NodeData: From<PlainGfaNodeData>, EdgeData: From<PlainGfaEdgeData>> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>
impl<IndexType: GraphIndexInteger, NodeData: From<PlainGfaNodeData>, EdgeData: From<PlainGfaEdgeData>> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>
pub fn read_gfa1( reader: impl BufRead, ) -> Result<BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>, GfaReadError>
Sourceimpl<IndexType: GraphIndexInteger, NodeData: GfaNodeData, EdgeData: GfaEdgeData> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>
impl<IndexType: GraphIndexInteger, NodeData: GfaNodeData, EdgeData: GfaEdgeData> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>
Sourceimpl<IndexType: GraphIndexInteger, NodeData, EdgeData> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>
impl<IndexType: GraphIndexInteger, NodeData, EdgeData> BidirectedAdjacencyArray<IndexType, NodeData, EdgeData>